transcribe_video = """
You are generating a video summary.
Create a summary of the provided video and its transcript. 
Respond in markdown.
"""

summarize_video = """
You are generating a video summary. 
Create a summary of the provided video without the frame by frame transcription. 
Respond in markdown.
"""



import os
import time

from roadguard.feed import file, model
from roadguard.constant import RG_SAMPLE_DATA_PATH

DEFAULT_VIDEO_PATH = os.path.join(
    RG_SAMPLE_DATA_PATH,
    "didi", "city-5s.mp4"
)


def report():
    frames = file.extract_frame(
        path=DEFAULT_VIDEO_PATH,
        seconds_per_frame=1
    )

    start = time.time()
    transcription = model.summarize_video(frames)

    print(f"Number of frames {len(frames)}")
    print(f"Transcription:\n{transcription}")
    print(f"Time taken: {time.time() - start}")



import time

import os
import cv2
import base64


def extract_frame(path: str, seconds_per_frame=1):
    base64Frames = []
    base_video_path, _ = os.path.splitext(path)

    video = cv2.VideoCapture(path)
    total_frames = int(video.get(cv2.CAP_PROP_FRAME_COUNT))
    fps = video.get(cv2.CAP_PROP_FPS)
    frames_to_skip = int(fps * seconds_per_frame)
    curr_frame = 0

    # Loop through the video and extract frames at specified sampling rate
    while curr_frame < total_frames - 1:
        video.set(cv2.CAP_PROP_POS_FRAMES, curr_frame)
        success, frame = video.read()
        if not success:
            break
        _, buffer = cv2.imencode(".jpg", frame)
        base64Frames.append(base64.b64encode(buffer).decode("utf-8"))
        curr_frame += frames_to_skip
    video.release()

    print(f"Extracted {len(base64Frames)} frames")
    return base64Frames



import cv2
import pyaudio
import wave
import speech_recognition as sr
import numpy as np
import threading


# Initialize class (for recognizing the speech)
def clip():
    r = sr.Recognizer()
    return r


def capture_audio(segment_length=5, filename_prefix="output"):
    # Setup the audio recording parameters
    FORMAT = pyaudio.paInt16  # Audio format (16-bit PCM)
    CHANNELS = 1  # Mono audio
    RATE = 44100  # Sample rate
    CHUNK = 1024  # Buffer size
    RECORD_SECONDS = segment_length  # Length of each audio file segment

    audio = pyaudio.PyAudio()

    # Start recording
    stream = audio.open(format=FORMAT, channels=CHANNELS,
                        rate=RATE, input=True,
                        frames_per_buffer=CHUNK)

    print("Recording...")

    try:
        while True:
            frames = []

            # Record data for a set number of seconds
            for _ in range(int(RATE / CHUNK * RECORD_SECONDS)):
                data = stream.read(CHUNK)
                frames.append(data)

            # Generate filename based on the current timestamp
            filename = f"{filename_prefix}_{int(time.time())}.wav"

            # Save the recorded data as a WAV file
            with wave.open(filename, 'wb') as wf:
                wf.setnchannels(CHANNELS)
                wf.setsampwidth(audio.get_sample_size(FORMAT))
                wf.setframerate(RATE)
                wf.writeframes(b''.join(frames))

            print(f"Saved: {filename}")

    except KeyboardInterrupt:
        print("Recording stopped")

    finally:
        # Stop and close the stream and terminate the PyAudio object
        stream.stop_stream()
        stream.close()
        audio.terminate()


# Function to apply mosaic to a region of interest (ROI)
def apply_mosaic(frame, x, y, w, h, factor=10):
    roi = frame[y:y + h, x:x + w]
    roi = cv2.resize(roi, (w // factor, h // factor), interpolation=cv2.INTER_LINEAR)
    roi = cv2.resize(roi, (w, h), interpolation=cv2.INTER_NEAREST)
    frame[y:y + h, x:x + w] = roi
    return frame


# Function to process video frames
def process_video(command):
    cap = cv2.VideoCapture(0)
    face_cascade = cv2.CascadeClassifier(cv2.data.haarcascades + 'haarcascade_frontalface_default.xml')
    plate_cascade = cv2.CascadeClassifier(cv2.data.haarcascades + 'haarcascade_licence_plate_rus_16stages.xml')

    while True:
        ret, frame = cap.read()
        if not ret:
            break

        # Detect faces and plates
        faces = face_cascade.detectMultiScale(frame, 1.3, 5)
        plates = plate_cascade.detectMultiScale(frame, 1.3, 5)

        # Apply mosaic to faces and plates
        for (x, y, w, h) in faces:
            frame = apply_mosaic(frame, x, y, w, h)
        for (x, y, w, h) in plates:
            frame = apply_mosaic(frame, x, y, w, h)

        # Display the resulting frame
        cv2.imshow('Video', frame)

        if cv2.waitKey(1) & 0xFF == ord('q'):
            break

    cap.release()
    cv2.destroyAllWindows()


# Main function to run the demo
def main():
    # Start a thread for audio capture
    while True:
        command = capture_audio()
        if command and 'start' in command.lower():
            process_video(command)


# Run the main function
if __name__ == "__main__":
    main()



import os
import sys
import yaml

RG_DIR = os.path.join(os.path.expanduser("~"), ".roadguard")
RG_CONFIG_FILE = os.path.join(RG_DIR, "config.yaml")
RG_SOURCE = os.path.dirname(os.path.abspath(__file__))

try:
    with open(RG_CONFIG_FILE, "r") as f:
        RG_CONFIG = yaml.load(f, Loader=yaml.SafeLoader)
except FileNotFoundError:
    print(f"Config file not found at {RG_CONFIG_FILE}")
    sys.exit(1)

os.environ.setdefault(
    "OPENAI_API_KEY",
    RG_CONFIG.get("OPENAI_API_KEY", "")
)

RG_SAMPLE_DATA_PATH = os.path.join(
    os.path.dirname(__file__),
    '..', '..', 'roadguard-sample-data')



from setuptools import setup, find_packages

setup(
    name="RoadGuard",
    version="0.0.1",
    description="RoadGuard library",
    author="RoadGuard Team",
    author_email="silveryfu@gmail.com",
    license="Apache License, Version 2.0",
    packages=find_packages(exclude=("tests",)),
    python_requires='>=3.8',
    include_package_data=True,
    install_requires = open('requirements.txt').readlines(),
)



import os
from openai import OpenAI

from roadguard import feed
from roadguard.feed import parameter, prompt


def transcribe_video(frames: list,
                     prompt=prompt.transcribe_video) -> str:
    client = OpenAI(api_key=os.environ.get('OPENAI_API_KEY'))

    response = client.chat.completions.create(
        model=parameter.MODEL,
        messages=[
            {"role": "system",
             "content": prompt},
            {"role": "user", "content": [
                "These are the frames from the video.",
                *map(lambda x: {"type": "image_url",
                                "image_url": {"url": f'data:image/jpg;base64,{x}',
                                              "detail": "low"}}, frames),
            ],
             }
        ],
        temperature=parameter.TEMPERATURE,
    )

    input_tokens = response.usage.total_tokens - response.usage.completion_tokens
    output_tokens = response.usage.completion_tokens

    feed.trace.add({
        "model": {
            "num_input_tokens": input_tokens,
            "num_output_tokens": output_tokens,
        }
    })

    return response.choices[0].message.content


def summarize_video(frames: list) -> str:
    return transcribe_video(
        frames, prompt=prompt.summarize_video
    )


def transcribe_audio(path: str) -> str:
    client = OpenAI(api_key=os.environ.get('OPENAI_API_KEY'))
    response = client.audio.transcriptions.create(
        model="whisper-1",
        file=open(path, "rb"),
    )
    return response.choices[0].message.content
